@@ -1,6 +1,7 @@
 from typing import TYPE_CHECKING
 
 import matplotlib.pyplot as plt
+import matplotlib as mpl
 import numpy as np
 
 if TYPE_CHECKING:
@@ -9,6 +10,10 @@ if TYPE_CHECKING:
 from signum.plotting.scaled_axes import ScaledAxes
 
 
+mpl.rcParams['axes.grid'] = True
+mpl.rcParams['grid.color'] = 'lightgrey'
+
+
 class Plotter:
     def __init__(self, n_rows=1, n_cols=1, title=None, **kwargs):
         fig, axes = plt.subplots(n_rows, n_cols, **kwargs)
@@ -28,9 +33,6 @@ class Plotter:
         if title:
             fig.suptitle(title)
 
-        for ax in axes.flatten():
-            ax.grid(color='lightgrey')
-
     def add_legend(self, **kwargs):
         """Add legend to each of the main grid axes."""
 
